summaryrefslogtreecommitdiff
path: root/gnu/usr.bin/perl/hints/dec_osf.sh
diff options
context:
space:
mode:
authorTodd C. Miller <millert@cvs.openbsd.org>2002-10-27 22:25:41 +0000
committerTodd C. Miller <millert@cvs.openbsd.org>2002-10-27 22:25:41 +0000
commitd85c2f57f17d991a6ca78d3e1c9f3308a2bbb271 (patch)
tree8c9a359433cbb3488b0a848e99bd869c76295dfd /gnu/usr.bin/perl/hints/dec_osf.sh
parent74cfb115ac810480c0000dc742b20383c1578bac (diff)
Resolve conflicts, remove old files, merge local changes
Diffstat (limited to 'gnu/usr.bin/perl/hints/dec_osf.sh')
-rw-r--r--gnu/usr.bin/perl/hints/dec_osf.sh137
1 files changed, 119 insertions, 18 deletions
diff --git a/gnu/usr.bin/perl/hints/dec_osf.sh b/gnu/usr.bin/perl/hints/dec_osf.sh
index ce3a40c77db..b3872fac126 100644
--- a/gnu/usr.bin/perl/hints/dec_osf.sh
+++ b/gnu/usr.bin/perl/hints/dec_osf.sh
@@ -60,18 +60,25 @@
cc=${cc:-cc}
+case "`$cc -v 2>&1 | grep cc`" in
+*gcc*) isgcc=gcc ;;
+esac
+
# do NOT, I repeat, *NOT* take away the leading tabs
# Configure Black Magic (TM)
# reset
_DEC_cc_style=
-case "`$cc -v 2>&1 | grep cc`" in
-*gcc*) _gcc_version=`$cc --version 2>&1 | tr . ' '`
- set $_gcc_version
- if test "$1" -lt 2 -o \( "$1" -eq 2 -a \( "$2" -lt 95 -o \( "$2" -eq 95 -a "$3" -lt 2 \) \) \); then
+case "$isgcc" in
+gcc) if [ "X$gccversion" = "X" ]; then
+ # Done too late in Configure if hinted
+ gccversion=`$cc --version | sed 's/.*(GCC) *//'`
+ fi
+ set $gccversion
+ if test "$1" -lt 2 -o \( "$1" -eq 2 -a \( "$2" -lt 95 -o \( "$2" -eq 95 -a "$3" -lt 3 \) \) \); then
cat >&4 <<EOF
*** Your cc seems to be gcc and its version ($_gcc_version) seems to be
*** less than 2.95.2. This is not a good idea since old versions of gcc
*** are known to produce buggy code when compiling Perl (and no doubt for
*** other programs, too).
***
@@ -100,7 +107,7 @@ EOF
fi
;;
*) # compile something small: taint.c is fine for this.
- ccversion=`cc -V | awk '/(Compaq|DEC) C/ {print $3}'`
+ ccversion=`cc -V | awk '/(Compaq|DEC) C/ {print $3}' | grep '^V'`
# the main point is the '-v' flag of 'cc'.
case "`cc -v -I. -c taint.c -o taint$$.o 2>&1`" in
*/gemc_cc*) # we have the new DEC GEM CC
@@ -116,8 +123,8 @@ EOF
esac
# be nauseatingly ANSI
-case "`$cc -v 2>&1 | grep gcc`" in
-*gcc*) ccflags="$ccflags -ansi"
+case "$isgcc" in
+gcc) ccflags="$ccflags -ansi"
;;
*) ccflags="$ccflags -std"
;;
@@ -129,13 +136,10 @@ esac
# we want optimisation
case "$optimize" in
-'') case "`$cc -v 2>&1 | grep gcc`" in
- *gcc*)
- optimize='-O3' ;;
+'') case "$isgcc" in
+ gcc) optimize='-O3' ;;
*) case "$_DEC_cc_style" in
- new) optimize='-O4'
- ccflags="$ccflags -fprm d -ieee"
- ;;
+ new) optimize='-O4' ;;
old) optimize='-O2 -Olimit 3200' ;;
esac
ccflags="$ccflags -D_INTRINSICS"
@@ -144,6 +148,15 @@ case "$optimize" in
;;
esac
+# we want dynamic fp rounding mode, and we want ieee exception semantics
+case "$isgcc" in
+gcc) ;;
+*) case "$_DEC_cc_style" in
+ new) ccflags="$ccflags -fprm d -ieee" ;;
+ esac
+ ;;
+esac
+
# Make glibpth agree with the compiler suite. Note that /shlib
# is not here. That's on purpose. Even though that's where libc
# really lives from V4.0 on, the linker (and /sbin/loader) won't
@@ -255,8 +268,8 @@ cat > UU/usethreads.cbu <<'EOCBU'
case "$usethreads" in
$define|true|[yY]*)
# Threads interfaces changed with V4.0.
- case "`$cc -v 2>&1 | grep gcc`" in
- *gcc*)ccflags="-D_REENTRANT $ccflags" ;;
+ case "$isgcc" in
+ gcc) ccflags="-D_REENTRANT $ccflags" ;;
*) case "`uname -r`" in
*[123].*) ccflags="-threads $ccflags" ;;
*) ccflags="-pthread $ccflags" ;;
@@ -273,6 +286,12 @@ $define|true|[yY]*)
usemymalloc='n'
;;
esac
+ # These symbols are renamed in <time.h> so
+ # that the Configure hasproto doesn't see them.
+ d_asctime_r_proto="$define"
+ d_ctime_r_proto="$define"
+ d_gmtime_r_proto="$define"
+ d_localtime_r_proto="$define"
;;
esac
EOCBU
@@ -281,10 +300,92 @@ cat > UU/uselongdouble.cbu <<'EOCBU'
# This script UU/uselongdouble.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use long doubles.
case "$uselongdouble" in
-$define|true|[yY]*) d_Gconvert='sprintf((b),"%.*Lg",(n),(x))' ;;
+$define|true|[yY]*)
+ case "`/usr/sbin/sizer -v`" in
+ *[1-4].0*) cat >&4 <<EOF
+
+***
+*** Sorry, you cannot use long doubles in pre-V5.0 releases of Tru64.
+***
+
+Cannot continue, aborting.
+
+EOF
+ exit 1
+ ;;
+ *)
+ # Test whether libc's been fixed yet.
+ cat >try.c <<\TRY
+#include <stdio.h>
+int main(int argc, char **argv)
+{
+ unsigned long uvmax = ~0UL;
+ long double ld = uvmax + 0.0L;
+ char buf1[30], buf2[30];
+
+ (void) sprintf(buf1, "%lu", uvmax);
+ (void) sprintf(buf2, "%.0Lf", ld);
+ return strcmp(buf1, buf2) != 0;
+}
+TRY
+ # Don't bother trying to work with Configure's idea of
+ # cc and the various flags. This might not work as-is
+ # with gcc -- but we're testing libc, not the compiler.
+ if cc -o try -std try.c && ./try
+ then
+ : ok
+ else
+ cat <<\UGLY >&4
+!
+Warning! Your libc has not yet been patched so that its "%Lf" format for
+printing long doubles shows all the significant digits. You will get errors
+in the t/op/numconvert test because of this. (The data is still good
+internally, and the "%e" format of printf() or sprintf() in perl will still
+produce valid results.) See README.tru64 for additional details.
+
+Continuing anyway.
+!
+UGLY
+ fi
+ $rm -f try try.c
+ esac
+ ;;
esac
EOCBU
+case "`/usr/sbin/sizer -v`" in
+*[1-4].0*) d_modfl=undef ;; # must wait till 5.0
+esac
+
+# Keep those leading tabs.
+ needusrshlib=''
+ old_LD_LIBRARY_PATH=$LD_LIBRARY_PATH
+for p in $loclibpth
+do
+ if test -n "`ls $p/libdb.so* 2>/dev/null`"; then
+ needusrshlib=yes
+ fi
+ if test -d $p; then
+ echo "Appending $p to LD_LIBRARY_PATH." >& 4
+ case "$LD_LIBRARY_PATH" in
+ '') LD_LIBRARY_PATH=$p ;;
+ *) LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$p ;;
+ esac
+ fi
+done
+case "$LD_LIBRARY_PATH" in
+"$old_LD_LIBRARY_PATH") ;;
+*) echo "LD_LIBRARY_PATH is now $LD_LIBRARY_PATH." >& 4 ;;
+esac
+# This is evil but I can't think of a nice workaround:
+# the /usr/shlib/libdb.so needs to be seen first,
+# or running Configure will fail.
+if test -n "$needusrshlib"; then
+ echo "Prepending /usr/shlib to loclibpth." >& 4
+ loclibpth="/usr/shlib $loclibpth"
+ echo "loclibpth is now $loclibpth." >& 4
+fi
+
#
# Unset temporary variables no more needed.
#
@@ -60,18 +60,25 @@
cat >&4 <<EOF
-*** Your cc seems to be gcc and its version ($_gcc_version) seems to be
-*** less than 2.95.2. This is not a good idea since old versions of gcc
+*** Your cc seems to be gcc and its version ($gccversion) seems to be
+*** less than 2.95.3. This is not a good idea since old versions of gcc
*** are known to produce buggy code when compiling Perl (and no doubt for
*** other programs, too).